@@ -17,5 +17,11 @@ finally:
 
 from .nludb import NLUDB
 from .embedding_index import EmbeddingIndex
+from .classifier import Classifier
 from .types.embedding_models import EmbeddingModels
-from .file import File
\ No newline at end of file
+from .types.classifier_models import ClassifierModels
+from .types.parsing_models import ParsingModels
+from .file import File
+from .types.model import ModelType, ModelAdapterType, LimitUnit, Model
+from .types.block_types import BlockTypes
+from .types.file_formats import FileFormats
\ No newline at end of file
